==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/RadialAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Array_$type, Point_$type, runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { ViewportUtils } from "./ViewportUtils";
import { PropertyMetadata } from "igniteui-react-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var RadialAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeries, _super);
    function RadialAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialAreaSeries.$;
        return _this;
    }
    RadialAreaSeries.prototype.bi = function () {
        return new RadialAreaSeries();
    };
    RadialAreaSeries.prototype.get_es = function () {
        return true;
    };
    RadialAreaSeries.prototype.cq = function () {
        return new RadialAreaSeriesView(this);
    };
    RadialAreaSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.adc = a;
    };
    RadialAreaSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialAreaSeries.prototype.o2 = function (a, b) {
        _super.prototype.o2.call(this, a, b);
        this.adc.c6();
    };
    RadialAreaSeries.prototype.aa1 = function (a, b) {
        _super.prototype.aa1.call(this, a, b);
        var c = b.by;
        var d = b.bx;
        var e = b.getEffectiveViewport();
        var f = b;
        if (b.o() && !c.isEmpty && !d.isEmpty && this.yq != null && this.yv != null) {
            var g = a.f;
            var h = g.count;
            var i = new List$1(Array_$type, 2, h);
            var j = 0;
            for (var k = 0; k < h; k++) {
                var l = new Array(4);
                i.add(l);
                l[0] = this.yy.d(a.f._inner[k][0], a.f._inner[k][1], c, d, e);
                l[1] = this.yy.e(a.f._inner[k][0], a.f._inner[k][1], c, d, e);
                l[2] = this.yy.d(a.f._inner[k][0], a.f._inner[k][2], c, d, e);
                var m = a.f._inner[k][2];
                l[3] = this.yy.e(a.f._inner[k][0], m, c, d, e);
                if (m > j) {
                    j = m;
                }
            }
            var n = ViewportUtils.e(0.5, c, d, e);
            var o = ViewportUtils.i(0.5, c, d, e);
            this.adb = { $type: Point_$type, x: n, y: o };
            var p = this.getEffectiveViewport1(f);
            this.y6.a2(this, this.zn(), runOn(this, this.ye), this.zw(b), this.zx(b));
            var q = false;
            var r = this.y6.b;
            if (r != null) {
                q = true;
            }
            if (q) {
                var s = new ScalerParams(0, b.by, b.bx, this.yq.ch, p);
                this.acs(g, -1, this.abw.count, this.yq, s, b.q);
            }
            var t = f.de;
            var u = f.df;
            var v = f.dc;
            var w = f.dd;
            this.y6.ad(t, true, false, true, true);
            this.y6.ad(u, true, false, true, true);
            this.y6.ad(v, false, true, false, false);
            this.y6.ad(w, false, true, false, false);
            f.c7(a.f.count, i, false, this.adc.cx.b, this.ib, runOn(this, this.act), this.add);
            v._opacity = this.y6.j * this.h7;
            w._opacity = 0.5 * this.y6.j * this.h7;
        }
    };
    RadialAreaSeries.prototype.q4 = function (a, b, c, d) {
        _super.prototype.q4.call(this, a, b, c, d);
        switch (b) {
            case RadialAreaSeries.$$p[0]:
                this.rm(false);
                this.qg();
                break;
        }
    };
    RadialAreaSeries.prototype.get_ab2 = function () {
        return true;
    };
    RadialAreaSeries.$t = markType(RadialAreaSeries, 'RadialAreaSeries', AnchoredRadialSeries.$);
    RadialAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:add:adf', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialAreaSeries;
}(AnchoredRadialSeries));
export { RadialAreaSeries };
/**
 * @hidden
 */
var RadialAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeriesView, _super);
    function RadialAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c5 = null;
        _this.dc = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.df = new Path();
        _this.c8 = new Path();
        _this.da = new Path();
        _this.c9 = new Path();
        _this.db = new Path();
        _this.c5 = a;
        return _this;
    }
    RadialAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.w1 = Defaults.e;
        }
    };
    RadialAreaSeriesView.prototype.c6 = function () {
        this.dc.an = null;
        this.de.an = null;
        this.dd.an = null;
        this.df.an = null;
        this.c8.an = null;
        this.da.an = null;
        this.c9.an = null;
        this.db.an = null;
        this.as();
    };
    RadialAreaSeriesView.prototype.c7 = function (a, b, c, d, e, f, g) {
        this.c1.abr.i(this.dc, this.de, this.dd, this.df, a, b, c, d, e, f, g);
        this.as();
    };
    RadialAreaSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    RadialAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.da.an = this.de.an;
        this.db.an = this.df.an;
        this.c8.an = this.dc.an;
        this.c9.an = this.dd.an;
        this.da._stroke = a;
        this.da.ad = this.e.ic + 3;
        this.db._stroke = a;
        this.db.ad = this.e.ic + 3;
        this.c8._fill = a;
        this.c8._opacity = 1;
        this.c9._fill = a;
        this.c9._opacity = 1;
    };
    RadialAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.c8);
                a.t(this.c9);
                a.t(this.da);
                a.t(this.db);
            }
            else {
                a.t(this.dc);
                a.t(this.dd);
                a.t(this.de);
                a.t(this.df);
            }
        }
    };
    RadialAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bb.exportPathData(a, this.de, "lowerShape", ["Lower"]);
        this.e.bb.exportPathData(a, this.df, "upperShape", ["Upper", "Main"]);
        this.e.bb.exportPathData(a, this.dd, "translucentShape", ["Translucent"]);
        this.e.bb.exportPathData(a, this.dc, "fillShape", ["Fill"]);
    };
    RadialAreaSeriesView.$t = markType(RadialAreaSeriesView, 'RadialAreaSeriesView', AnchoredRadialSeriesView.$);
    return RadialAreaSeriesView;
}(AnchoredRadialSeriesView));
export { RadialAreaSeriesView };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/RadialAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Array_$type, Point_$type, runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { ViewportUtils } from "./ViewportUtils";
import { ChartSelection } from "./ChartSelection";
import { PropertyMetadata } from "igniteui-react-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var RadialAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeries, _super);
    function RadialAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialAreaSeries.$;
        return _this;
    }
    RadialAreaSeries.prototype.bj = function () {
        return new RadialAreaSeries();
    };
    RadialAreaSeries.prototype.get_eu = function () {
        return true;
    };
    RadialAreaSeries.prototype.cs = function () {
        return new RadialAreaSeriesView(this);
    };
    RadialAreaSeries.prototype.q1 = function (a) {
        _super.prototype.q1.call(this, a);
        this.adp = a;
    };
    RadialAreaSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialAreaSeries.prototype.o5 = function (a, b) {
        _super.prototype.o5.call(this, a, b);
        this.adp.c6();
    };
    RadialAreaSeries.prototype.abc = function (a, b) {
        _super.prototype.abc.call(this, a, b);
        var c = b.by;
        var d = b.bx;
        var e = b.getEffectiveViewport();
        var f = b;
        if (b.o() && !c.isEmpty && !d.isEmpty && this.yz != null && this.y5 != null) {
            var g = a.f;
            var h = g.count;
            var i = new List$1(Array_$type, 2, h);
            var j = 0;
            for (var k = 0; k < h; k++) {
                var l = new Array(4);
                i.add(l);
                l[0] = this.y8.d(a.f._inner[k][0], a.f._inner[k][1], c, d, e);
                l[1] = this.y8.e(a.f._inner[k][0], a.f._inner[k][1], c, d, e);
                l[2] = this.y8.d(a.f._inner[k][0], a.f._inner[k][2], c, d, e);
                var m = a.f._inner[k][2];
                l[3] = this.y8.e(a.f._inner[k][0], m, c, d, e);
                if (m > j) {
                    j = m;
                }
            }
            var n = ViewportUtils.e(0.5, c, d, e);
            var o = ViewportUtils.i(0.5, c, d, e);
            this.ado = { $type: Point_$type, x: n, y: o };
            var p = this.getEffectiveViewport1(f);
            this.zg.a2(this, this.zx(), runOn(this, this.yn), this.z6(b), this.z7(b));
            var q = false;
            var r = this.zg.b;
            if (r != null) {
                q = true;
            }
            if (q) {
                var s = new ScalerParams(0, b.by, b.bx, this.yz.ch, p);
                this.ac5(g, -1, this.ab8.count, this.yz, s, b.q);
            }
            var t = f.de;
            var u = f.df;
            var v = f.dc;
            var w = f.dd;
            this.zg.ad(t, true, false, true, true);
            this.zg.ad(u, true, false, true, true);
            this.zg.ad(v, false, true, false, false);
            this.zg.ad(w, false, true, false, false);
            f.c7(a.f.count, i, false, this.adp.cx.b, this.id, runOn(this, this.ac6), this.adq);
            v._opacity = this.zg.j * this.h9;
            w._opacity = 0.5 * this.zg.j * this.h9;
        }
    };
    RadialAreaSeries.prototype.ak = function (a, b) {
        var c = new List$1(ChartSelection.$, 0);
        this.p4(a, c, b);
        return c.toArray();
    };
    RadialAreaSeries.prototype.p4 = function (a, b, c) {
        this.ac2(a, b, c, this.y0);
    };
    RadialAreaSeries.prototype.q9 = function (a, b, c, d) {
        _super.prototype.q9.call(this, a, b, c, d);
        switch (b) {
            case RadialAreaSeries.$$p[0]:
                this.rr(false);
                this.ql();
                break;
        }
    };
    RadialAreaSeries.prototype.get_ace = function () {
        return true;
    };
    RadialAreaSeries.$t = markType(RadialAreaSeries, 'RadialAreaSeries', AnchoredRadialSeries.$);
    RadialAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:adq:ads', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialAreaSeries;
}(AnchoredRadialSeries));
export { RadialAreaSeries };
/**
 * @hidden
 */
var RadialAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeriesView, _super);
    function RadialAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c5 = null;
        _this.dc = new Path();
        _this.de = new Path();
        _this.dd = new Path();
        _this.df = new Path();
        _this.c8 = new Path();
        _this.da = new Path();
        _this.c9 = new Path();
        _this.db = new Path();
        _this.c5 = a;
        return _this;
    }
    RadialAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.xa = Defaults.e;
        }
    };
    RadialAreaSeriesView.prototype.c6 = function () {
        this.dc.an = null;
        this.de.an = null;
        this.dd.an = null;
        this.df.an = null;
        this.c8.an = null;
        this.da.an = null;
        this.c9.an = null;
        this.db.an = null;
        this.as();
    };
    RadialAreaSeriesView.prototype.c7 = function (a, b, c, d, e, f, g) {
        this.c1.ab3.i(this.dc, this.de, this.dd, this.df, a, b, c, d, e, f, g);
        this.as();
    };
    RadialAreaSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    RadialAreaSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.da.an = this.de.an;
        this.db.an = this.df.an;
        this.c8.an = this.dc.an;
        this.c9.an = this.dd.an;
        this.da._stroke = a;
        this.da.ad = this.e.ie + 3;
        this.db._stroke = a;
        this.db.ad = this.e.ie + 3;
        this.c8._fill = a;
        this.c8._opacity = 1;
        this.c9._fill = a;
        this.c9._opacity = 1;
    };
    RadialAreaSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.c8);
                a.t(this.c9);
                a.t(this.da);
                a.t(this.db);
            }
            else {
                a.t(this.dc);
                a.t(this.dd);
                a.t(this.de);
                a.t(this.df);
            }
        }
    };
    RadialAreaSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bc.exportPathData(a, this.de, "lowerShape", ["Lower"]);
        this.e.bc.exportPathData(a, this.df, "upperShape", ["Upper", "Main"]);
        this.e.bc.exportPathData(a, this.dd, "translucentShape", ["Translucent"]);
        this.e.bc.exportPathData(a, this.dc, "fillShape", ["Fill"]);
    };
    RadialAreaSeriesView.$t = markType(RadialAreaSeriesView, 'RadialAreaSeriesView', AnchoredRadialSeriesView.$);
    return RadialAreaSeriesView;
}(AnchoredRadialSeriesView));
export { RadialAreaSeriesView };
